@@ -797,7 +797,7 @@ test_that("Plot with base is not error-free", {
 
   #dput(getFingerprint(file = "test.png"))
   orig <- switch(Sys.info()["sysname"],
-                 Darwin = "F3B42F4A8C0FF049",
+                 Darwin = "F3B5A64A8C0FF049",
                  Linux = "F3B42E4A8C0FF0C9",
                  Windows = "F3B42E4A8C0FF0C9"
   )
