@@ -3,7 +3,9 @@ test_that("paths file does not work correctly", {
   params <- list(.globals = list(burnStats = "npixelsburned", stackName = "landscape"))
   modules <- list("randomLandscapes", "caribouMovement", "fireSpread")
 
-  tempPath <- checkPath(tempdir())
+  tempPath <- file.path(tempdir(), "test-paths") %>% checkPath(create = TRUE)
+
+  on.exit(unlink(tempPath, recursive = TRUE), add = TRUE)
 
   # test for mixture of named and unnamed
   paths <- list(modulePath = system.file("sampleModules", package = "SpaDES"),
